package com.imdbInfo.base;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;

import net.sf.json.JSONObject;
import net.sf.json.JSONSerializer;

public class ImdbLookup {
	private static final String DEFAULT_CHARACTER_SET = "UTF-8";
	private static final String BASIC_API_URL = "http://www.imdbapi.com/?";
	private static final String TITLE_PARAM = "t=";
	private static final String YEAR_PARAM = "&y=";
	
	public static String getJSONStringOf(String urlSpec) throws Exception {
		URL url = new URL(urlSpec);
		URLConnection connection = url.openConnection();

		BufferedReader reader = new BufferedReader(new InputStreamReader(
				connection.getInputStream()));
		String line = "";
		StringBuilder builder = new StringBuilder();
		while ((line = reader.readLine()) != null) {
			builder.append(line);
		}
		return builder.toString();
	}
	
	public static Movie buildMovieFromJSONObject(JSONObject json) {
		Movie movie = new Movie.Builder(json.getString("Title"),json.getInt("Year"))
						.setDirector(json.getString("Director"))
						.setVotes(json.getInt("Votes"))
						.setRating(json.getDouble("Rating"))
						.setGenre(json.getString("Genre")).build();
						
		return movie;
	}

	public static Movie getMovieInfo(String title, int year) throws Exception{
		String encodedTitle = urlEncode(title);
		
		String text = ImdbLookup.getJSONStringOf(BASIC_API_URL + TITLE_PARAM + encodedTitle + YEAR_PARAM + year);

		JSONObject json = (JSONObject) JSONSerializer.toJSON(text);
		
		return ImdbLookup.buildMovieFromJSONObject(json);
	}

	public static Movie getMovieInfo(String title) throws Exception{
		String encodedTitle = urlEncode(title);
		
		String text = ImdbLookup.getJSONStringOf(BASIC_API_URL + TITLE_PARAM + encodedTitle);
		
		JSONObject json = (JSONObject) JSONSerializer.toJSON(text);
		
		return ImdbLookup.buildMovieFromJSONObject(json);
	}
	
	@SuppressWarnings("deprecation")
	private static String urlEncode(String title) throws UnsupportedEncodingException{
		return URLEncoder.encode(title, DEFAULT_CHARACTER_SET);
	}
}
