package com.imdbInfo.base;


public class Movie {

	private String title;
	private int year;
	private double rating;
	private int votes;
	private String genre;
	private String director;

	public String getGenre() {
		return genre;
	}

	public void setGenre(String genre) {
		this.genre = genre;
	}

	private Movie(Builder builder) {
		this.title = builder.title;
		this.year = builder.year;
		this.rating = builder.rating;
		this.votes = builder.votes;
		this.genre = builder.genre;
		this.director = builder.director;
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("Title: ").append(this.title).append(", ");
		sb.append("Year: ").append(this.year).append(", ");
		sb.append("Director: ").append(this.director).append(", ");
		sb.append("Votes: ").append(this.votes).append(", ");
		sb.append("Rating: ").append(this.rating).append(", ");
		
		return sb.toString();
	}
	
	public static class Builder {
		// mandatory parameter
		private final String title;
		private int year;

		// optional
		private double rating;
		private int votes;
		private String genre;
		private String director;

		public Movie build() {
			return new Movie(this);
		}

		public Builder(String title,int year) {
			this.title = title;
			this.year= year;
		}

		public Builder setVotes(int votes) {
			this.votes = votes;
			return this;
		}

		public Builder setRating(double rating) {
			this.rating = rating;
			return this;
		}

		public Builder setGenre(String genre) {
			this.genre = genre;
			return this;
		}

		public Builder setDirector(String director) {
			this.director = director;
			return this;
		}
		
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public double getRating() {
		return rating;
	}

	public void setRating(double rating) {
		this.rating = rating;
	}

	public int getVotes() {
		return votes;
	}

	public void setVotes(int votes) {
		this.votes = votes;
	}

	public int getYear() {
		return year;
	}

	public void setYear(int year) {
		this.year = year;
	}

	public String getDirector() {
		return director;
	}

	public void setDirector(String director) {
		this.director = director;
	}

}
